

set -ex



spm_decode --help >/dev/null || [[ $? == 1 ]]
spm_encode --help >/dev/null || [[ $? == 1 ]]
spm_export_vocab --help >/dev/null || [[ $? == 1 ]]
spm_normalize --help >/dev/null || [[ $? == 1 ]]
spm_train --help >/dev/null || [[ $? == 1 ]]
exit 0
